@@ -1,13 +1,13 @@
 use strict;
 use warnings;
 package IPC::Lockfile;
-$IPC::Lockfile::VERSION = '0.03';
+$IPC::Lockfile::VERSION = '0.04';
 # ABSTRACT: run only one instance of a program at a time using flock
 use Fcntl qw(:flock);
 
 # lexical filehandles dont work!
-open LOCKFILE, '<', $0  or die "Unable to create the lockfile $0 $!\n";
-flock LOCKFILE, LOCK_EX|LOCK_NB or die "$0 is running!\n";
+open our $LOCKFILE, '<', $0  or die "Unable to create the lockfile $0 $!\n";
+flock $LOCKFILE, LOCK_EX|LOCK_NB or die "$0 is running!\n";
 
 
 1;
@@ -24,7 +24,7 @@ IPC::Lockfile - run only one instance of a program at a time using flock
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
